@@ -24,8 +24,7 @@ from typing import Any, Callable, Dict, Optional
 
 from numpy import ndarray
 
-from .typing import CvxoptReadyMatrix
-from .typing import DenseOrCSCMatrix
+from .typing import CvxoptReadyMatrix, DenseOrCSCMatrix
 
 available_solvers = []
 dense_solvers = []
@@ -45,6 +44,8 @@ cvxopt_solve_qp: Optional[
             Optional[CvxoptReadyMatrix],
             Optional[CvxoptReadyMatrix],
             Optional[CvxoptReadyMatrix],
+            Optional[CvxoptReadyMatrix],
+            Optional[CvxoptReadyMatrix],
             Optional[str],
             Optional[CvxoptReadyMatrix],
             bool,
@@ -76,6 +77,8 @@ cvxpy_solve_qp: Optional[
             Optional[ndarray],
             Optional[ndarray],
             Optional[ndarray],
+            Optional[ndarray],
+            Optional[ndarray],
             Optional[str],
             bool,
         ],
@@ -106,6 +109,8 @@ ecos_solve_qp: Optional[
             Optional[ndarray],
             Optional[ndarray],
             Optional[ndarray],
+            Optional[ndarray],
+            Optional[ndarray],
             bool,
         ],
         Optional[ndarray],
@@ -135,6 +140,8 @@ gurobi_solve_qp: Optional[
             Optional[ndarray],
             Optional[ndarray],
             Optional[ndarray],
+            Optional[ndarray],
+            Optional[ndarray],
             bool,
         ],
         Optional[ndarray],
@@ -164,6 +171,8 @@ mosek_solve_qp: Optional[
             Optional[CvxoptReadyMatrix],
             Optional[CvxoptReadyMatrix],
             Optional[CvxoptReadyMatrix],
+            Optional[CvxoptReadyMatrix],
+            Optional[CvxoptReadyMatrix],
             bool,
         ],
         Optional[ndarray],
@@ -193,6 +202,8 @@ osqp_solve_qp: Optional[
             Optional[DenseOrCSCMatrix],
             Optional[DenseOrCSCMatrix],
             Optional[DenseOrCSCMatrix],
+            Optional[DenseOrCSCMatrix],
+            Optional[DenseOrCSCMatrix],
             bool,
         ],
         Optional[ndarray],
@@ -222,6 +233,8 @@ qpoases_solve_qp: Optional[
             Optional[ndarray],
             Optional[ndarray],
             Optional[ndarray],
+            Optional[ndarray],
+            Optional[ndarray],
             bool,
             int,
         ],
@@ -252,6 +265,8 @@ qpswift_solve_qp: Optional[
             Optional[ndarray],
             Optional[ndarray],
             Optional[ndarray],
+            Optional[ndarray],
+            Optional[ndarray],
             bool,
         ],
         Optional[ndarray],
@@ -281,6 +296,8 @@ quadprog_solve_qp: Optional[
             Optional[ndarray],
             Optional[ndarray],
             Optional[ndarray],
+            Optional[ndarray],
+            Optional[ndarray],
             bool,
         ],
         Optional[ndarray],
@@ -310,6 +327,8 @@ scs_solve_qp: Optional[
             Optional[DenseOrCSCMatrix],
             Optional[ndarray],
             Optional[ndarray],
+            Optional[ndarray],
+            Optional[ndarray],
             float,
             float,
             bool,
