@@ -1,7 +1,7 @@
 #!/usr/bin/env python
 # -*- coding: utf-8 -*-
 #
-# Copyright (C) 2016-2021 Stéphane Caron <stephane.caron@normalesup.org>
+# Copyright (C) 2016-2022 Stéphane Caron and the qpsolvers contributors.
 #
 # This file is part of qpsolvers.
 #
@@ -20,19 +20,7 @@
 
 """Types for solve_qp function arguments."""
 
-from typing import Union
-
-from numpy import ndarray
-from scipy.sparse import csc_matrix
-
-try:
-    from cvxopt import spmatrix
-
-    Matrix = Union[ndarray, csc_matrix, spmatrix]
-    Vector = Union[ndarray, csc_matrix, spmatrix]
-except ImportError:
-    Matrix = Union[ndarray, csc_matrix]  # type: ignore
-    Vector = Union[ndarray, csc_matrix]  # type: ignore
+from .solvers.conversions.typing import Matrix, Vector
 
 __all__ = [
     "Matrix",
