@@ -33,7 +33,7 @@ from scipy.sparse import csc_matrix
 
 from qpsolvers import available_solvers, sparse_solvers
 from qpsolvers import solve_qp, solve_safer_qp
-from qpsolvers.exceptions import SolverNotFound
+from qpsolvers.exceptions import NoSolverSelected, SolverNotFound
 
 # Raising a ValueError when the problem is unbounded below is desired but not
 # achieved by some solvers. Here are the behaviors observed as of March 2022.
@@ -117,6 +117,14 @@ class TestSolveQP(unittest.TestCase):
         h = -2.0 * ones((n,))
         return P, q, G, h
 
+    def test_no_solver_selected(self):
+        """
+        Check that NoSolverSelected is raised when applicable.
+        """
+        P, q, G, h, A, b = self.get_dense_problem()
+        with self.assertRaises(NoSolverSelected):
+            solve_qp(P, q, G, h, A, b, solver=None)
+
     def test_solver_not_found(self):
         """
         Check that SolverNotFound is raised when the solver does not exist.
@@ -193,6 +201,26 @@ class TestSolveQP(unittest.TestCase):
                 {"P": P, "q": q, "G": G[0], "h": h0, "A": A, "b": b},
                 {"P": P, "q": q, "G": G, "h": h, "A": A[0], "b": b0},
                 {"P": P, "q": q, "G": G[0], "h": h0, "A": A[0], "b": b0},
+                {
+                    "P": P,
+                    "q": q,
+                    "G": G[0],
+                    "h": h0,
+                    "A": A[0],
+                    "b": b0,
+                    "lb": lb,
+                    "ub": None,
+                },
+                {
+                    "P": P,
+                    "q": q,
+                    "G": G[0],
+                    "h": h0,
+                    "A": A[0],
+                    "b": b0,
+                    "lb": None,
+                    "ub": ub,
+                },
                 {
                     "P": P,
                     "q": q,
@@ -384,7 +412,7 @@ class TestSolveQP(unittest.TestCase):
         def test(self):
             P, q, G, h, _, _ = self.get_dense_problem()
             if solver in sparse_solvers:
-                with self.assertRaises(AssertionError):
+                with self.assertRaises(NotImplementedError):
                     solve_safer_qp(P, q, G, h, sr=1e-4, solver=solver)
                 return
             x = solve_safer_qp(P, q, G, h, sr=1e-4, solver=solver)
